@@ -4,8 +4,6 @@ use warnings;
 package Net::Google::PicasaWeb::Base;
 use Moose;
 
-with 'MooseX::Role::Matcher' => { default_match => 'id' };
-
 =head1 NAME
 
 Net::Google::PicasaWeb::Base - base class
@@ -28,7 +26,7 @@ has service => (
     is => 'rw',
     isa => 'Net::Google::PicasaWeb',
     required => 1,
-    weak_ref => 1,
+    weaken => 1,
 );
 
 =head2 twig
